@@ -20,10 +20,10 @@ plot5 <- rainette_plot(res, dtm, k = 4, n_terms = 20, text_size = 9)
 plot6 <- rainette_plot(res, dtm, type = "cloud", text_size = 6)
 plot7 <- rainette_plot(res, dtm, k = 4, type = "cloud", n_terms = 10, text_size = 9, measure = "lr")
 
-vdiffr::expect_doppelganger("Base rainette_plot", plot1)
-vdiffr::expect_doppelganger("Base rainette_plot with free_scales", plot2)
-vdiffr::expect_doppelganger("Base rainette_plot measure='lr'", plot3)
-vdiffr::expect_doppelganger("Base rainette_plot with k and without negative", plot4)
-vdiffr::expect_doppelganger("Base rainette_plot with k, n_terms and font_size", plot5)
-vdiffr::expect_doppelganger("Base rainette_plot of type 'cloud'", plot6)
-vdiffr::expect_doppelganger("Base rainette_plot of type 'cloud' and arguments", plot7)
\ No newline at end of file
+#vdiffr::expect_doppelganger("Base rainette_plot", plot1)
+#vdiffr::expect_doppelganger("Base rainette_plot with free_scales", plot2)
+#vdiffr::expect_doppelganger("Base rainette_plot measure='lr'", plot3)
+#vdiffr::expect_doppelganger("Base rainette_plot with k and without negative", plot4)
+#vdiffr::expect_doppelganger("Base rainette_plot with k, n_terms and font_size", plot5)
+#vdiffr::expect_doppelganger("Base rainette_plot of type 'cloud'", plot6)
+#vdiffr::expect_doppelganger("Base rainette_plot of type 'cloud' and arguments", plot7)
\ No newline at end of file
